@@ -50,9 +50,6 @@ order_python() {
       fi
     fi
   done
-  if [ -z "$selected_version" ]; then
-    selected_version=python
-  fi
   echo $selected_version
 }
 
@@ -203,6 +200,12 @@ case $HOSTNAME in
   *.corp.google.com|*.c.googlers.com) export CLOUDSDK_INTERNAL_USER_FAST_UPDATE=true;;
 esac
 
+if [ -z "$OPENSSL_CONF" ]; then
+    if [ -f "$HOME/.config/gcloud/ecp_openssl.cnf" ]; then
+     export OPENSSL_CONF="$HOME/.config/gcloud/ecp_openssl.cnf"
+   fi
+fi
+
 # </cloud-sdk-sh-preamble>
 
 if [ -z "$CLOUDSDK_PYTHON" ]; then
