@@ -18,6 +18,7 @@ from __future__ import division
 from __future__ import unicode_literals
 
 import re
+from typing import MutableMapping
 
 from googlecloudsdk.api_lib.cloudbuild import cloudbuild_exceptions
 from googlecloudsdk.core import yaml
@@ -25,7 +26,7 @@ from googlecloudsdk.core import yaml
 
 def LoadYamlFromPath(path):
   try:
-    data = yaml.load_path(path)
+    data = yaml.load_path(path, round_trip=True, preserve_quotes=True)
   except yaml.Error as e:
     raise cloudbuild_exceptions.ParserError(path, e.inner_error)
   if not yaml.dict_like(data):
@@ -47,21 +48,35 @@ def UnrecognizedFields(message):
             f=", ".join(unrecognized_fields)))
 
 
-def WorkflowTriggerTransform(trigger):
+def WorkflowTriggerTransform(trigger, resources):
   """Transform workflow trigger according to the proto.
 
   Refer to go/gcb-v2-filters to understand more details.
 
   Args:
     trigger: the trigger defined in the workflow YAML.
+    resources: the workflow resources dictionary.
   Raises:
     InvalidYamlError: The eventType was unsupported.
   """
   trigger["id"] = trigger.pop("name")
-  event_source = trigger.pop("eventSource")
-  trigger["eventSource"] = {
-      "id": event_source,
-  }
+  event_source = trigger.pop("source", trigger.pop("eventSource", ""))
+  if event_source:
+    if event_source not in resources:
+      raise cloudbuild_exceptions.InvalidYamlError(
+          "Unfound event source: {event_source} in workflow resources".format(
+              event_source=event_source))
+    if "secret" in resources[event_source]:
+      trigger["webhookSecret"] = {"id": event_source}
+    else:
+      trigger["source"] = {"id": event_source}
+  if "secret" in trigger:
+    secret = trigger.pop("secret")
+    if secret not in resources:
+      raise cloudbuild_exceptions.InvalidYamlError(
+          "Unfound secret: {secret} in workflow resources".format(
+              secret=secret))
+    trigger["webhookSecret"] = {"id": secret}
   event_type_mapping = {
       "branch-push": "PUSH_BRANCH",
       "tag-push": "PUSH_TAG",
@@ -75,20 +90,43 @@ def WorkflowTriggerTransform(trigger):
       trigger["eventType"] = mapped_event_type
     else:
       raise cloudbuild_exceptions.InvalidYamlError(
-          "Unsupported event type: {event_type}".format(event_type=event_type))
-  for key, value in trigger.pop("filters").items():
+          ("Unsupported event type: {event_type}. "
+           "Supported: {event_types}").format(
+               event_type=event_type,
+               event_types=",".join(event_type_mapping.keys())))
+  for key, value in trigger.pop("filters", {}).items():
     trigger[key] = value
   if "gitRef" in trigger and "regex" in trigger["gitRef"]:
     trigger["gitRef"]["nameRegex"] = trigger["gitRef"].pop("regex")
   ParamDictTransform(trigger.get("params", []))
 
 
+def _ConvertToUpperCase(input_map: MutableMapping[str, str], key: str):
+  if key in input_map:
+    input_map[key] = input_map[key].upper()
+
+
 def ParamSpecTransform(param_spec):
   if "default" in param_spec:
     param_spec["default"] = ParamValueTransform(param_spec["default"])
 
-  if "type" in param_spec:
-    param_spec["type"] = param_spec["type"].upper()
+  _ConvertToUpperCase(param_spec, "type")
+
+
+def TaskResultTransform(task_result):
+  _ConvertToUpperCase(task_result, "type")
+
+  for property_name in task_result.get("properties", []):
+    PropertySpecTransform(task_result["properties"][property_name])
+
+
+def PropertySpecTransform(property_spec):
+  """Mutates the given property spec from Tekton to GCB format.
+
+  Args:
+    property_spec: A Tekton-compliant property spec.
+  """
+  _ConvertToUpperCase(property_spec, "type")
 
 
 def ParamDictTransform(params):
