@@ -29,6 +29,7 @@ NONCE_LABEL = 'client.knative.dev/nonce'
 MIN_SCALE_ANNOTATION = 'autoscaling.knative.dev/minScale'
 MAX_SCALE_ANNOTATION = 'autoscaling.knative.dev/maxScale'
 SESSION_AFFINITY_ANNOTATION = 'run.googleapis.com/sessionAffinity'
+MESH_ANNOTATION = 'run.googleapis.com/mesh'
 
 
 class Revision(container_resource.ContainerResource):
@@ -61,11 +62,6 @@ class Revision(container_resource.ContainerResource):
       return cond[self._ACTIVE_CONDITION]['status']
     return None
 
-  def _EnsureMeta(self):
-    if self.metadata is None:
-      self.metadata = self._messages.ObjectMeta()
-    return self.metadata
-
   @property
   def concurrency(self):
     """The concurrency number in the revisionTemplate.
