@@ -151,6 +151,113 @@ class CloudApi(object):
     """
     raise NotImplementedError('create_anywhere_cache must be overridden.')
 
+  def get_anywhere_cache(
+      self, bucket_name, zone
+  ):
+    """Gets Anywhere Cache Instance for a zone in bucket.
+
+    Args:
+      bucket_name (str): The name of the bucket.
+      zone (str): Name of the zonal location.
+
+    Returns:
+      AnywhereCache: the Anywhere Cache Instance
+
+    Raises:
+      CloudApiError: API returned an error.
+      NotImplementedError: This function was not implemented by a class using
+        this interface.
+    """
+    raise NotImplementedError('get_anywhere_cache must be overridden.')
+
+  def pause_anywhere_cache(
+      self, bucket_name, zone
+  ):
+    """Pauses Anywhere Cache Instance for a zone in bucket.
+
+    Args:
+      bucket_name (str): The name of the bucket.
+      zone (str): Name of the zonal location.
+
+    Raises:
+      CloudApiError: API returned an error.
+      NotImplementedError: This function was not implemented by a class using
+        this interface.
+    """
+    raise NotImplementedError('pause_anywhere_cache must be overridden.')
+
+  def resume_anywhere_cache(self, bucket_name, zone):
+    """Resumes Anywhere Cache in particular zone of a bucket.
+
+    Args:
+      bucket_name (str): The name of the bucket where the Anywhere Cache should
+        be resumed.
+      zone (str): Name of the zonal location where the Anywhere Cache should be
+        resumed.
+
+    Raises:
+      CloudApiError: API returned an error.
+      NotImplementedError: This function was not implemented by a class using
+        this interface.
+    """
+    raise NotImplementedError('resume_anywhere_cache must be overridden.')
+
+  def disable_anywhere_cache(self, bucket_name, zone):
+    """Disables Anywhere Cache in particular zone of a bucket.
+
+    Args:
+      bucket_name (str): The name of the bucket where the Anywhere Cache should
+        be disabled.
+      zone (str): Name of the zonal location where the Anywhere Cache should be
+        disabled.
+
+    Raises:
+      CloudApiError: API returned an error.
+      NotImplementedError: This function was not implemented by a class using
+        this interface.
+    """
+    raise NotImplementedError('disable_anywhere_cache must be overridden.')
+
+  def list_anywhere_caches(self, bucket_name):
+    """Lists all Anywhere Cache instances of the bucket.
+
+    Args:
+      bucket_name (str): The name of the bucket.
+
+    Yields:
+      Iterator over gcs_resource_reference.GcsAnywhereCacheResource objects.
+
+    Raises:
+      CloudApiError: API returned an error.
+      NotImplementedError: This function was not implemented by a class using
+        this interface.
+    """
+    raise NotImplementedError('list_anywhere_cache must be overridden.')
+
+  def patch_anywhere_cache(
+      self, bucket_name, zone, admission_policy=None, ttl=None
+  ):
+    """Updates Anywhere Cache instance of a bucket.
+
+    Args:
+      bucket_name (str): The name of the bucket where the Anywhere Cache should
+        be updated.
+      zone (str): Name of the zonal location where the Anywhere Cache should be
+        updated.
+      admission_policy (str|None): The cache admission policy decides for each
+        cache miss, that is whether to insert the missed block or not.
+      ttl (str|None): Cache entry time-to-live in seconds
+
+    Returns:
+      GoogleLongrunningOperation Apitools object for creating caches.
+
+    Raises:
+      CloudApiError: API returned an error.
+      NotImplementedError: This function was not implemented by a class using
+        this interface.
+    """
+    raise NotImplementedError('patch_anywhere_cache must be overridden.')
+
   def create_bucket(self, bucket_resource, request_config, fields_scope=None):
     """Creates a new bucket with the specified metadata.
 
