@@ -20,6 +20,7 @@ from __future__ import unicode_literals
 
 import hashlib
 import os
+import re
 import uuid
 
 from apitools.base.py import encoding
@@ -272,6 +273,8 @@ def _SetBuildSteps(
           '--pack', 'Image value must be in the *gcr.io* or *pkg.dev* namespace'
       )
     env = buildpack[0].get('env')
+    # envs example: ["key1=value1", "key2=value2"]
+    envs = buildpack[0].get('envs')
     builder = buildpack[0].get('builder')
     steps = []
     pack_args = [
@@ -281,9 +284,14 @@ def _SetBuildSteps(
         'cloudbuild',
     ]
     build_tags = [_GetBuildTag(builder)]
+    # Keep both env and envs for backward compatibility.
     if env is not None:
       pack_args.append('--env')
       pack_args.append(env)
+    if envs is not None:
+      for env in envs:
+        pack_args.append('--env')
+        pack_args.append(env)
     if builder is not None:
       pack_args.append('--builder')
       pack_args.append(builder)
@@ -355,6 +363,8 @@ def SetSource(
     no_source,
     source,
     gcs_source_staging_dir,
+    arg_dir,
+    arg_revision,
     arg_git_source_dir,
     arg_git_source_revision,
     ignore_file,
@@ -399,6 +409,18 @@ def SetSource(
       )
       return build_config
 
+    if re.match(
+        r'projects/.*/locations/.*/connections/.*/repositories/.*', source
+    ):
+      build_config.source = messages.Source(
+          connectedRepository=messages.ConnectedRepository(
+              repository=source,
+              dir=arg_dir,
+              revision=arg_revision,
+          )
+      )
+      return build_config
+
     suffix = '.tgz'
     if source.startswith('gs://') or os.path.isfile(source):
       _, suffix = os.path.splitext(source)
@@ -665,6 +687,8 @@ def CreateBuildConfig(
     arg_machine_type,
     arg_disk_size,
     arg_worker_pool,
+    arg_dir,
+    arg_revision,
     arg_git_source_dir,
     arg_git_source_revision,
     buildpack,
@@ -696,6 +720,8 @@ def CreateBuildConfig(
         no_source,
         source,
         gcs_source_staging_dir,
+        arg_dir,
+        arg_revision,
         arg_git_source_dir,
         arg_git_source_revision,
         ignore_file,
@@ -729,6 +755,8 @@ def CreateBuildConfigAlpha(
     arg_memory,
     arg_vcpu_count,
     arg_worker_pool,
+    arg_dir,
+    arg_revision,
     arg_git_source_dir,
     arg_git_source_revision,
     buildpack,
@@ -760,6 +788,8 @@ def CreateBuildConfigAlpha(
         no_source,
         source,
         gcs_source_staging_dir,
+        arg_dir,
+        arg_revision,
         arg_git_source_dir,
         arg_git_source_revision,
         ignore_file,
