@@ -75,10 +75,6 @@ class ExecutionNotFoundError(exceptions.Error):
   """Indicates that a provided execution name was not found."""
 
 
-class IntegrationNotFoundError(exceptions.Error):
-  """Indicates that a provided integration name was not found."""
-
-
 class DockerVersionError(exceptions.Error):
   """Indicates an error in determining the docker version."""
 
@@ -217,14 +213,6 @@ class UnsupportedOperationError(exceptions.Error):
   """The requested operation is not supported."""
 
 
-class IntegrationsOperationError(exceptions.Error):
-  """An error encountered when waiting for LRO to finish."""
-
-
-class UnsupportedIntegrationsLocationError(exceptions.Error):
-  """An error encountered when an unsupported location is provided."""
-
-
 class KubernetesExceptionParser(object):
   """Converts a kubernetes exception to an object."""
 
@@ -295,3 +283,10 @@ class KubernetesExceptionParser(object):
       return [messages[k] for k in sorted(messages)]
     except KeyError:
       return []
+
+
+class InvalidRuntimeLanguage(exceptions.Error):
+  def __init__(self, invalid_runtime):
+    super(InvalidRuntimeLanguage, self).__init__(
+        f'Runtime language [{invalid_runtime}] is not supported'
+    )
