@@ -565,11 +565,12 @@ class ConfigServiceV2GrpcAsyncIOTransport(ConfigServiceV2Transport):
             Awaitable[logging_config.LogView]]:
         r"""Return a callable for the update view method over gRPC.
 
-        Updates a view on a log bucket. This method replaces the
-        following fields in the existing view with values from the new
-        view: ``filter``. If an ``UNAVAILABLE`` error is returned, this
-        indicates that system is not in a state where it can update the
-        view. If this occurs, please try again in a few minutes.
+        Updates a view on a log bucket. This method replaces the value
+        of the ``filter`` field from the existing view with the
+        corresponding value from the new view. If an ``UNAVAILABLE``
+        error is returned, this indicates that system is not in a state
+        where it can update the view. If this occurs, please try again
+        in a few minutes.
 
         Returns:
             Callable[[~.UpdateViewRequest],
@@ -706,9 +707,9 @@ class ConfigServiceV2GrpcAsyncIOTransport(ConfigServiceV2Transport):
             Awaitable[logging_config.LogSink]]:
         r"""Return a callable for the update sink method over gRPC.
 
-        Updates a sink. This method replaces the following fields in the
-        existing sink with values from the new sink: ``destination``,
-        and ``filter``.
+        Updates a sink. This method replaces the values of the
+        ``destination`` and ``filter`` fields of the existing sink with
+        the corresponding values from the new sink.
 
         The updated sink might also have a new ``writer_identity``; see
         the ``unique_writer_identity`` field.
@@ -1009,7 +1010,7 @@ class ConfigServiceV2GrpcAsyncIOTransport(ConfigServiceV2Transport):
         Gets the Logging CMEK settings for the given resource.
 
         Note: CMEK for the Log Router can be configured for Google Cloud
-        projects, folders, organizations and billing accounts. Once
+        projects, folders, organizations, and billing accounts. Once
         configured for an organization, it applies to all projects and
         folders in the Google Cloud organization.
 
@@ -1048,10 +1049,13 @@ class ConfigServiceV2GrpcAsyncIOTransport(ConfigServiceV2Transport):
         all projects and folders in the Google Cloud organization.
 
         [UpdateCmekSettings][google.logging.v2.ConfigServiceV2.UpdateCmekSettings]
-        will fail if 1) ``kms_key_name`` is invalid, or 2) the
-        associated service account does not have the required
-        ``roles/cloudkms.cryptoKeyEncrypterDecrypter`` role assigned for
-        the key, or 3) access to the key is disabled.
+        fails when any of the following are true:
+
+        -  The value of ``kms_key_name`` is invalid.
+        -  The associated service account doesn't have the required
+           ``roles/cloudkms.cryptoKeyEncrypterDecrypter`` role assigned
+           for the key.
+        -  Access to the key is disabled.
 
         See `Enabling CMEK for Log
         Router <https://cloud.google.com/logging/docs/routing/managed-encryption>`__
@@ -1081,16 +1085,13 @@ class ConfigServiceV2GrpcAsyncIOTransport(ConfigServiceV2Transport):
             Awaitable[logging_config.Settings]]:
         r"""Return a callable for the get settings method over gRPC.
 
-        Gets the Log Router settings for the given resource.
+        Gets the settings for the given resource.
 
-        Note: Settings for the Log Router can be get for Google Cloud
-        projects, folders, organizations and billing accounts. Currently
-        it can only be configured for organizations. Once configured for
-        an organization, it applies to all projects and folders in the
-        Google Cloud organization.
+        Note: Settings can be retrieved for Google Cloud projects,
+        folders, organizations, and billing accounts.
 
-        See `Enabling CMEK for Log
-        Router <https://cloud.google.com/logging/docs/routing/managed-encryption>`__
+        See [View default resource settings for Logging]
+        (https://cloud.google.com/logging/docs/default-settings#view-org-settings)
         for more information.
 
         Returns:
@@ -1117,24 +1118,25 @@ class ConfigServiceV2GrpcAsyncIOTransport(ConfigServiceV2Transport):
             Awaitable[logging_config.Settings]]:
         r"""Return a callable for the update settings method over gRPC.
 
-        Updates the Log Router settings for the given resource.
-
-        Note: Settings for the Log Router can currently only be
-        configured for Google Cloud organizations. Once configured, it
-        applies to all projects and folders in the Google Cloud
-        organization.
+        Updates the settings for the given resource. This method applies
+        to all feature configurations for organization and folders.
 
         [UpdateSettings][google.logging.v2.ConfigServiceV2.UpdateSettings]
-        will fail if 1) ``kms_key_name`` is invalid, or 2) the
-        associated service account does not have the required
-        ``roles/cloudkms.cryptoKeyEncrypterDecrypter`` role assigned for
-        the key, or 3) access to the key is disabled. 4) ``location_id``
-        is not supported by Logging. 5) ``location_id`` violate
-        OrgPolicy.
+        fails when any of the following are true:
 
-        See `Enabling CMEK for Log
-        Router <https://cloud.google.com/logging/docs/routing/managed-encryption>`__
-        for more information.
+        -  The value of ``storage_location`` either isn't supported by
+           Logging or violates the location OrgPolicy.
+        -  The ``default_sink_config`` field is set, but it has an
+           unspecified filter write mode.
+        -  The value of ``kms_key_name`` is invalid.
+        -  The associated service account doesn't have the required
+           ``roles/cloudkms.cryptoKeyEncrypterDecrypter`` role assigned
+           for the key.
+        -  Access to the key is disabled.
+
+        See [Configure default settings for organizations and folders]
+        (https://cloud.google.com/logging/docs/default-settings) for
+        more information.
 
         Returns:
             Callable[[~.UpdateSettingsRequest],
