@@ -18,6 +18,7 @@ from __future__ import division
 from __future__ import unicode_literals
 
 from googlecloudsdk.api_lib.apphub import discovered_workloads as apis
+from googlecloudsdk.api_lib.apphub import utils as api_lib_utils
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.apphub import flags
 
@@ -25,9 +26,9 @@ from googlecloudsdk.command_lib.apphub import flags
 _DETAILED_HELP = {
     'DESCRIPTION': '{description}',
     'EXAMPLES': """ \
-        To list all discovered workloads, run:
+        To list all DiscoveredWorkloads in location `us-east1`, run:
 
-          $ {command}
+          $ {command} --location=us-east1
         """,
 }
 
@@ -50,6 +51,11 @@ class List(base.ListCommand):
   def Args(parser):
     flags.AddListDiscoveredWorkloadFlags(parser)
     parser.display_info.AddFormat(_FORMAT)
+    parser.display_info.AddUriFunc(
+        api_lib_utils.MakeGetUriFunc(
+            'apphub.projects.locations.discoveredWorkloads'
+        )
+    )
 
   def Run(self, args):
     """Run the list command."""
