@@ -67,6 +67,8 @@ def _CommonArgs(
     support_network_queue_count=False,
     support_storage_pool=False,
     support_maintenance_interval=False,
+    support_specific_then_x_affinity=False,
+    support_graceful_shutdown=False,
 ):
   """Adding arguments applicable for creating instance templates."""
   parser.display_info.AddFormat(instance_templates_flags.DEFAULT_LIST_FORMAT)
@@ -178,6 +180,7 @@ Specifies the reservation for instances created from this template.
       affinity_text="""\
 The type of reservation for instances created from this template.
 """,
+      support_specific_then_x_affinity=support_specific_then_x_affinity,
   )
 
   parser.display_info.AddCacheUpdater(completers.InstanceTemplatesCompleter)
@@ -190,6 +193,9 @@ The type of reservation for instances created from this template.
   if support_maintenance_interval:
     instances_flags.AddMaintenanceIntervalArgs(parser)
 
+  if support_graceful_shutdown:
+    instances_flags.AddGracefulShutdownArgs(parser)
+
 
 def _ValidateInstancesFlags(
     args, support_kms=False, support_max_run_duration=False
@@ -547,6 +553,8 @@ def _RunCreate(
     support_storage_pool=False,
     support_partner_metadata=False,
     support_maintenance_interval=False,
+    support_specific_then_x_affinity=False,
+    support_graceful_shutdown=False,
 ):
   """Common routine for creating instance template.
 
@@ -591,6 +599,10 @@ def _RunCreate(
       support_partner_metadata: Indicate whether partner metadata is supported.
       support_maintenance_interval: Indicate whether maintenance interval was
         set.
+      support_specific_then_x_affinity: Indicate whether specific_then_x was
+        set.
+      support_graceful_shutdown: Indicate whether graceful shutdown is
+        supported.
 
   Returns:
       A resource object dispatched by display.Displayer().
@@ -771,6 +783,10 @@ def _RunCreate(
       args.maintenance_interval if should_set_maintenance_interval else None
   )
 
+  graceful_shutdown = instance_utils.ExtractGracefulShutdownFromArgs(
+      args, support_graceful_shutdown
+  )
+
   scheduling = instance_utils.CreateSchedulingMessage(
       messages=client.messages,
       maintenance_policy=args.maintenance_policy,
@@ -786,6 +802,7 @@ def _RunCreate(
       termination_time=termination_time,
       local_ssd_recovery_timeout=local_ssd_recovery_timeout,
       maintenance_interval=maintenance_interval,
+      graceful_shutdown=graceful_shutdown,
   )
 
   if args.no_service_account:
@@ -906,7 +923,9 @@ def _RunCreate(
   )
 
   instance_template.properties.reservationAffinity = (
-      instance_utils.GetReservationAffinity(args, client)
+      instance_utils.GetReservationAffinity(
+          args, client, support_specific_then_x_affinity
+      )
   )
 
   instance_template.properties.confidentialInstanceConfig = (
@@ -1073,6 +1092,8 @@ class Create(base.CreateCommand):
   _support_max_run_duration = False
   _support_region_instance_template = True
   _support_subnet_region = False
+  _support_confidential_compute_type = False
+  _support_confidential_compute_type_tdx = False
   _support_network_attachments = False
   _support_replica_zones = True
   _support_local_ssd_size = True
@@ -1082,6 +1103,8 @@ class Create(base.CreateCommand):
   _support_storage_pool = False
   _support_partner_metadata = False
   _support_local_ssd_recovery_timeout = True
+  _support_specific_then_x_affinity = False
+  _support_graceful_shutdown = False
 
   @classmethod
   def Args(cls, parser):
@@ -1103,12 +1126,19 @@ class Create(base.CreateCommand):
         support_network_queue_count=cls._support_network_queue_count,
         support_storage_pool=cls._support_storage_pool,
         support_local_ssd_recovery_timeout=cls._support_local_ssd_recovery_timeout,
+        support_specific_then_x_affinity=cls._support_specific_then_x_affinity,
+        support_graceful_shutdown=cls._support_graceful_shutdown,
     )
     instances_flags.AddMinCpuPlatformArgs(parser, base.ReleaseTrack.GA)
     instances_flags.AddPrivateIpv6GoogleAccessArgForTemplate(
         parser, utils.COMPUTE_GA_API_VERSION
     )
-    instances_flags.AddConfidentialComputeArgs(parser)
+    instances_flags.AddConfidentialComputeArgs(
+        parser,
+        support_confidential_compute_type=cls
+        ._support_confidential_compute_type,
+        support_confidential_compute_type_tdx=cls
+        ._support_confidential_compute_type_tdx)
     instance_templates_flags.AddKeyRevocationActionTypeArgs(parser)
 
   def Run(self, args):
@@ -1134,12 +1164,16 @@ class Create(base.CreateCommand):
         support_max_run_duration=self._support_max_run_duration,
         support_region_instance_template=self._support_region_instance_template,
         support_subnet_region=self._support_subnet_region,
+        support_confidential_compute_type=self._support_confidential_compute_type,
+        support_confidential_compute_type_tdx=self._support_confidential_compute_type_tdx,
         support_replica_zones=self._support_replica_zones,
         support_performance_monitoring_unit=self._support_performance_monitoring_unit,
         support_internal_ipv6_reservation=self._support_internal_ipv6_reservation,
         support_storage_pool=self._support_storage_pool,
         support_partner_metadata=self._support_partner_metadata,
         support_local_ssd_recovery_timeout=self._support_local_ssd_recovery_timeout,
+        support_specific_then_x_affinity=self._support_specific_then_x_affinity,
+        support_graceful_shutdown=self._support_graceful_shutdown,
     )
 
 
@@ -1169,6 +1203,8 @@ class CreateBeta(Create):
   _support_max_run_duration = True
   _support_region_instance_template = True
   _support_subnet_region = False
+  _support_confidential_compute_type = True
+  _support_confidential_compute_type_tdx = False
   _support_network_attachments = False
   _support_replica_zones = True
   _support_local_ssd_recovery_timeout = True
@@ -1179,6 +1215,8 @@ class CreateBeta(Create):
   _support_storage_pool = False
   _support_partner_metadata = False
   _support_maintenance_interval = True
+  _support_specific_then_x_affinity = True
+  _support_graceful_shutdown = False
 
   @classmethod
   def Args(cls, parser):
@@ -1201,12 +1239,19 @@ class CreateBeta(Create):
         support_network_queue_count=cls._support_network_queue_count,
         support_storage_pool=cls._support_storage_pool,
         support_maintenance_interval=cls._support_maintenance_interval,
+        support_specific_then_x_affinity=cls._support_specific_then_x_affinity,
+        support_graceful_shutdown=cls._support_graceful_shutdown,
     )
     instances_flags.AddMinCpuPlatformArgs(parser, base.ReleaseTrack.BETA)
     instances_flags.AddPrivateIpv6GoogleAccessArgForTemplate(
         parser, utils.COMPUTE_BETA_API_VERSION
     )
-    instances_flags.AddConfidentialComputeArgs(parser)
+    instances_flags.AddConfidentialComputeArgs(
+        parser,
+        support_confidential_compute_type=cls
+        ._support_confidential_compute_type,
+        support_confidential_compute_type_tdx=cls
+        ._support_confidential_compute_type_tdx)
     instances_flags.AddPostKeyRevocationActionTypeArgs(parser)
     instance_templates_flags.AddKeyRevocationActionTypeArgs(parser)
 
@@ -1234,6 +1279,8 @@ class CreateBeta(Create):
         support_max_run_duration=self._support_max_run_duration,
         support_region_instance_template=self._support_region_instance_template,
         support_subnet_region=self._support_subnet_region,
+        support_confidential_compute_type=self._support_confidential_compute_type,
+        support_confidential_compute_type_tdx=self._support_confidential_compute_type_tdx,
         support_replica_zones=self._support_replica_zones,
         support_local_ssd_recovery_timeout=self._support_local_ssd_recovery_timeout,
         support_performance_monitoring_unit=self._support_performance_monitoring_unit,
@@ -1241,6 +1288,8 @@ class CreateBeta(Create):
         support_storage_pool=self._support_storage_pool,
         support_partner_metadata=self._support_partner_metadata,
         support_maintenance_interval=self._support_maintenance_interval,
+        support_specific_then_x_affinity=self._support_specific_then_x_affinity,
+        support_graceful_shutdown=self._support_graceful_shutdown,
     )
 
 
@@ -1282,6 +1331,8 @@ class CreateAlpha(Create):
   _support_storage_pool = True
   _support_partner_metadata = True
   _support_maintenance_interval = True
+  _support_specific_then_x_affinity = True
+  _support_graceful_shutdown = True
 
   @classmethod
   def Args(cls, parser):
@@ -1305,6 +1356,8 @@ class CreateAlpha(Create):
         support_network_queue_count=cls._support_network_queue_count,
         support_storage_pool=cls._support_storage_pool,
         support_maintenance_interval=cls._support_maintenance_interval,
+        support_specific_then_x_affinity=cls._support_specific_then_x_affinity,
+        support_graceful_shutdown=cls._support_graceful_shutdown,
     )
     instances_flags.AddLocalNvdimmArgs(parser)
     instances_flags.AddMinCpuPlatformArgs(parser, base.ReleaseTrack.ALPHA)
@@ -1357,6 +1410,8 @@ class CreateAlpha(Create):
         support_storage_pool=self._support_storage_pool,
         support_partner_metadata=self._support_partner_metadata,
         support_maintenance_interval=self._support_maintenance_interval,
+        support_specific_then_x_affinity=self._support_specific_then_x_affinity,
+        support_graceful_shutdown=self._support_graceful_shutdown,
     )
 
 
