@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google LLC. All Rights Reserved.
+# Copyright 2023 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -66,7 +66,8 @@ class Create(base.CreateCommand):
         type=str,
         help=textwrap.dedent("""\
           Path to file containing the signature to store, or `-` to read
-          signature from stdin."""))
+          signature from stdin."""),
+    )
     parser.add_argument(
         '--payload-file',
         required=False,
@@ -82,7 +83,8 @@ class Create(base.CreateCommand):
           NOTE: If you sign a payload with e.g. different whitespace or
           formatting, you must explicitly provide the payload content via this
           flag.
-          """))
+          """),
+    )
 
     flags.AddConcepts(
         parser,
@@ -98,7 +100,8 @@ class Create(base.CreateCommand):
               be able to read this attestor and must have the
               `containeranalysis.notes.attachOccurrence` permission for the
               Attestor's underlying Note resource (usually via the
-              `containeranalysis.notes.attacher` role).""")),
+              `containeranalysis.notes.attacher` role)."""),
+        ),
     )
 
     parser.add_argument(
@@ -112,7 +115,8 @@ class Create(base.CreateCommand):
 
           For PGP keys, this must be the version 4, full 160-bit fingerprint,
           expressed as a 40 character hexadecimal string. See
-          https://tools.ietf.org/html/rfc4880#section-12.2 for details."""))
+          https://tools.ietf.org/html/rfc4880#section-12.2 for details."""),
+    )
 
     parser.add_argument(
         '--validate',
@@ -121,21 +125,24 @@ class Create(base.CreateCommand):
         help=textwrap.dedent("""\
           Whether to validate that the Attestation can be verified by the
           provided Attestor.
-        """))
+        """),
+    )
 
   def Run(self, args):
     project_ref = resources.REGISTRY.Parse(
         properties.VALUES.core.project.Get(required=True),
         collection='cloudresourcemanager.projects',
     )
-    normalized_artifact_url = binauthz_command_util.NormalizeArtifactUrl(
-        args.artifact_url)
+    artifact_url_without_scheme = binauthz_command_util.RemoveArtifactUrlScheme(
+        args.artifact_url
+    )
     signature = console_io.ReadFromFileOrStdin(args.signature_file, binary=True)
     if args.payload_file:
       payload = files.ReadBinaryFileContents(args.payload_file)
     else:
       payload = binauthz_command_util.MakeSignaturePayload(
-          normalized_artifact_url)
+          artifact_url_without_scheme
+      )
 
     attestor_ref = args.CONCEPTS.attestor.Parse()
     api_version = apis.GetApiVersion(self.ReleaseTrack())
@@ -144,28 +151,29 @@ class Create(base.CreateCommand):
     # TODO(b/79709480): Add other types of attestors if/when supported.
     note_ref = resources.REGISTRY.ParseResourceId(
         'containeranalysis.projects.notes',
-        client.GetNoteAttr(attestor).noteReference, {})
+        client.GetNoteAttr(attestor).noteReference,
+        {},
+    )
 
     validation_enabled = 'validate' in args and args.validate
     validation_callback = functools.partial(
         validation.validate_attestation,
         attestor_ref=attestor_ref,
-        # Call V1 API for validation when using the alpha track. (The beta track
-        # uses V1Beta1, which is mapped to the same service as V1.)
-        # TODO(b/159263189): Replace with just api_version after removing
-        # ValidationHelperV1Alpha2 service.
-        api_version=apis.V1
-        if self.ReleaseTrack() == base.ReleaseTrack.ALPHA else api_version)
+        api_version=api_version,
+    )
 
-    return containeranalysis.Client().CreateAttestationOccurrence(
+    return containeranalysis.Client(
+        ca_apis.GetApiVersion(self.ReleaseTrack())
+    ).CreateAttestationOccurrence(
         project_ref=project_ref,
         note_ref=note_ref,
-        artifact_url=normalized_artifact_url,
+        artifact_url=artifact_url_without_scheme,
         public_key_id=args.public_key_id,
         signature=signature,
         plaintext=payload,
-        validation_callback=(validation_callback
-                             if validation_enabled else None),
+        validation_callback=(
+            validation_callback if validation_enabled else None
+        ),
     )
 
 
@@ -200,7 +208,8 @@ class CreateWithPkixSupport(base.CreateCommand):
         type=str,
         help=textwrap.dedent("""\
           Path to file containing the signature to store, or `-` to read
-          signature from stdin."""))
+          signature from stdin."""),
+    )
     parser.add_argument(
         '--payload-file',
         required=False,
@@ -216,15 +225,8 @@ class CreateWithPkixSupport(base.CreateCommand):
           NOTE: If you sign a payload with e.g. different whitespace or
           formatting, you must explicitly provide the payload content via this
           flag.
-          """))
-    parser.add_argument(
-        '--validate',
-        action='store_true',
-        default=False,
-        help=textwrap.dedent("""\
-          Whether to validate that the Attestation can be verified by the
-          provided Attestor.
-        """))
+          """),
+    )
 
     flags.AddConcepts(
         parser,
@@ -240,7 +242,8 @@ class CreateWithPkixSupport(base.CreateCommand):
               be able to read this attestor and must have the
               `containeranalysis.notes.attachOccurrence` permission for the
               Attestor's underlying Note resource (usually via the
-              `containeranalysis.notes.attacher` role).""")),
+              `containeranalysis.notes.attacher` role)."""),
+        ),
     )
 
     parser.add_argument(
@@ -257,50 +260,63 @@ class CreateWithPkixSupport(base.CreateCommand):
 
           For PGP keys, this must be the version 4, full 160-bit fingerprint,
           expressed as a 40 character hexadecimal string. See
-          https://tools.ietf.org/html/rfc4880#section-12.2 for details."""))
+          https://tools.ietf.org/html/rfc4880#section-12.2 for details."""),
+    )
+
+    parser.add_argument(
+        '--validate',
+        action='store_true',
+        default=False,
+        help=textwrap.dedent("""\
+          Whether to validate that the Attestation can be verified by the
+          provided Attestor.
+        """),
+    )
 
   def Run(self, args):
     project_ref = resources.REGISTRY.Parse(
         properties.VALUES.core.project.Get(required=True),
         collection='cloudresourcemanager.projects',
     )
-    normalized_artifact_url = binauthz_command_util.NormalizeArtifactUrl(
-        args.artifact_url)
+    artifact_url_without_scheme = binauthz_command_util.RemoveArtifactUrlScheme(
+        args.artifact_url
+    )
     signature = console_io.ReadFromFileOrStdin(args.signature_file, binary=True)
     if args.payload_file:
       payload = files.ReadBinaryFileContents(args.payload_file)
     else:
       payload = binauthz_command_util.MakeSignaturePayload(
-          normalized_artifact_url)
+          artifact_url_without_scheme
+      )
 
     attestor_ref = args.CONCEPTS.attestor.Parse()
     api_version = apis.GetApiVersion(self.ReleaseTrack())
-    attestor = attestors.Client(api_version).Get(attestor_ref)
+    client = attestors.Client(api_version)
+    attestor = client.Get(attestor_ref)
     # TODO(b/79709480): Add other types of attestors if/when supported.
     note_ref = resources.REGISTRY.ParseResourceId(
         'containeranalysis.projects.notes',
-        attestor.userOwnedDrydockNote.noteReference, {})
+        client.GetNoteAttr(attestor).noteReference,
+        {},
+    )
 
     validation_enabled = 'validate' in args and args.validate
     validation_callback = functools.partial(
         validation.validate_attestation,
         attestor_ref=attestor_ref,
-        # Call V1 API for validation when using the alpha track. (The beta track
-        # uses V1Beta1, which is mapped to the same service as V1.)
-        # TODO(b/159263189): Replace with just api_version after removing
-        # ValidationHelperV1Alpha2 service.
-        api_version=apis.V1
-        if self.ReleaseTrack() == base.ReleaseTrack.ALPHA else api_version)
+        api_version=api_version,
+    )
 
-    client = containeranalysis.Client(
-        ca_apis.GetApiVersion(self.ReleaseTrack()))
-    return client.CreateAttestationOccurrence(
+    return containeranalysis.Client(
+        ca_apis.GetApiVersion(self.ReleaseTrack())
+    ).CreateAttestationOccurrence(
         project_ref=project_ref,
         note_ref=note_ref,
-        artifact_url=normalized_artifact_url,
+        artifact_url=artifact_url_without_scheme,
         public_key_id=args.public_key_id,
         signature=signature,
         plaintext=payload,
-        validation_callback=(validation_callback
-                             if validation_enabled else None),
+        validation_callback=(
+            validation_callback if validation_enabled else None
+        ),
     )
