@@ -24,26 +24,39 @@ from googlecloudsdk.command_lib.org_policies import arguments
 from googlecloudsdk.command_lib.org_policies import utils
 from googlecloudsdk.core import log
 
+DETAILED_HELP = {
+    'DESCRIPTION':
+        """\
+        Deletes an organization policy.
+        """,
+    'EXAMPLES':
+        """\
+        To delete the policy associated with the constraint 'gcp.resourceLocations'
+        and the Project 'foo-project', run:
 
-@base.Hidden
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.GA)
+        $ {command} gcp.resourceLocations --project=foo-project
+        """,
+}
+
+
+@base.ReleaseTracks(base.ReleaseTrack.GA)
 class Delete(base.Command):
-  r"""Delete an organization policy.
-
-  Deletes an organization policy.
-
-  ## EXAMPLES
-
-  To delete the policy associated with the constraint 'gcp.resourceLocations'
-  and the Project 'foo-project', run:
-
-   $ {command} gcp.resourceLocations --project=foo-project
-  """
+  """Delete an organization policy."""
 
   @staticmethod
   def Args(parser):
     arguments.AddConstraintArgToParser(parser)
     arguments.AddResourceFlagsToParser(parser)
+    parser.add_argument(
+        '--etag',
+        hidden=True,
+        metavar='ETAG',
+        help=(
+            'The current top-level etag of the Policy. If an etag is provided'
+            ' and does not match the current etag of the Policy, deletion will'
+            ' fail with a concurrent error.'
+        ),
+    )
 
   def Run(self, args):
     """Deletes an organization policy.
@@ -57,14 +70,12 @@ class Delete(base.Command):
     Returns:
        If the policy is deleted, then messages.GoogleProtobufEmpty.
     """
-    policy_service = org_policy_service.PolicyService(self.ReleaseTrack())
-    org_policy_messages = org_policy_service.OrgPolicyMessages(
-        self.ReleaseTrack())
-
+    org_policy_api = org_policy_service.OrgPolicyApi(self.ReleaseTrack())
     policy_name = utils.GetPolicyNameFromArgs(args)
 
-    delete_request = org_policy_messages.OrgpolicyPoliciesDeleteRequest(
-        name=policy_name)
-    delete_response = policy_service.Delete(delete_request)
+    delete_response = org_policy_api.DeletePolicy(policy_name, args.etag)
     log.DeletedResource(policy_name, 'policy')
     return delete_response
+
+
+Delete.detailed_help = DETAILED_HELP
